gefixte version 03122015

Dependencies:   EthernetInterface mbed-rtos

Fork of Telemetrie_eth_h2m by Hochschule München

Revision:
4:5881695ba67a
Parent:
3:94a735c744ff
Child:
5:a96e4e59c710
--- a/Telemetry.cpp	Sun Nov 22 13:48:21 2015 +0000
+++ b/Telemetry.cpp	Sun Nov 22 14:00:29 2015 +0000
@@ -114,9 +114,10 @@
 
 
 /** Init Ethernet interface
   * ohne DHCP max. 2.5 Sekunden 
 */
-bool Telemetry::InitEthernetConnection(const char* IPAdress, const char* SubNetMask, const char* GateWay)
+bool Telemetry::InitEthernetConnection(const char* IPAddress, const char* SubNetMask, const char* GateWay)
 {   
     bool ReturnValue = false;
     #ifdef DEBUG
@@ -127,7 +128,7 @@
     //Schnittstelle nur einmal initialisieren, sonst gibt es Fehler!
     if (!InitSucceed)
     {
-        if (eth.init(IPAdress, SubNetMask, GateWay)==0)  //Init Interface
+        if (eth.init(IPAddress, SubNetMask, GateWay)==0)  //Init Interface
         {
             InitSucceed = true;
         }
@@ -114,9 +114,10 @@
 
 /** Init Ethernet interface
-  * ohne DHCP max. 2.5 Sekunden 
+  * ohne DHCP max. 2.5 Sekunden
+  * @ param IPAddress Interface IP 
 */